import FormData from "form-data";
import { SmartlingBaseApi } from "../base";
import { SmartlingAuthApi } from "../auth";
import { Logger } from "../logger";
import { FtsUploadedFileDto } from "./dto/fts-uploaded-file-dto";
import { FtsUploadFileParameters } from "./params/fts-upload-file-parameters";
import { TranslationDto } from "./dto/translation-dto";
import { TranslateFileParameters } from "./params/translate-file-parameters";
import { TranslationStatusDto } from "./dto/translation-status-dto";
import { LanguageDetectionDto } from "./dto/language-detection-dto";
import { LanguageDetectionStatusDto } from "./dto/language-detection-status-dto";
import { TranslatedFileDto } from "./dto/translated-file-dto";
export declare class SmartlingFileTranslationsApi extends SmartlingBaseApi {
    constructor(smartlingApiBaseUrl: string, authApi: SmartlingAuthApi, logger: Logger);
    uploadFile(accountUid: string, parameters: FtsUploadFileParameters): Promise<FtsUploadedFileDto>;
    translateFile(accountUid: string, fileUid: string, params: TranslateFileParameters): Promise<TranslationDto>;
    getTranslationProgress(accountUid: string, fileUid: string, mtUid: string): Promise<TranslationStatusDto>;
    downloadTranslatedFile(accountUid: string, fileUid: string, mtUid: string, localeId: string): Promise<string>;
    downloadTranslatedFileWithMetadata(accountUid: string, fileUid: string, mtUid: string, localeId: string): Promise<TranslatedFileDto>;
    downloadTranslatedFiles(accountUid: string, fileUid: string, mtUid: string): Promise<ArrayBuffer>;
    downloadTranslatedFilesWithMetadata(accountUid: string, fileUid: string, mtUid: string): Promise<TranslatedFileDto>;
    cancelFileTranslation(accountUid: string, fileUid: string, mtUid: string): Promise<void>;
    detectFileLanguage(accountUid: string, fileUid: string): Promise<LanguageDetectionDto>;
    getLanguageDetectionProgress(accountUid: string, fileUid: string, languageDetectionUid: string): Promise<LanguageDetectionStatusDto>;
    static fixContentTypeHeaderCase(form: FormData): Record<string, unknown>;
    private static downloadResponseToTranslatedFileDto;
}
